// Copyright 2022 Google LLC All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// This code was autogenerated. Do not edit directly.

// Code generated by client-gen. DO NOT EDIT.

package versioned

import (
	"fmt"

	agonesv1 "agones.dev/agones/pkg/client/clientset/versioned/typed/agones/v1"
	allocationv1 "agones.dev/agones/pkg/client/clientset/versioned/typed/allocation/v1"
	autoscalingv1 "agones.dev/agones/pkg/client/clientset/versioned/typed/autoscaling/v1"
	multiclusterv1 "agones.dev/agones/pkg/client/clientset/versioned/typed/multicluster/v1"
	discovery "k8s.io/client-go/discovery"
	rest "k8s.io/client-go/rest"
	flowcontrol "k8s.io/client-go/util/flowcontrol"
)

type Interface interface {
	Discovery() discovery.DiscoveryInterface
	AgonesV1() agonesv1.AgonesV1Interface
	AllocationV1() allocationv1.AllocationV1Interface
	AutoscalingV1() autoscalingv1.AutoscalingV1Interface
	MulticlusterV1() multiclusterv1.MulticlusterV1Interface
}

// Clientset contains the clients for groups. Each group has exactly one
// version included in a Clientset.
type Clientset struct {
	*discovery.DiscoveryClient
	agonesV1       *agonesv1.AgonesV1Client
	allocationV1   *allocationv1.AllocationV1Client
	autoscalingV1  *autoscalingv1.AutoscalingV1Client
	multiclusterV1 *multiclusterv1.MulticlusterV1Client
}

// AgonesV1 retrieves the AgonesV1Client
func (c *Clientset) AgonesV1() agonesv1.AgonesV1Interface {
	return c.agonesV1
}

// AllocationV1 retrieves the AllocationV1Client
func (c *Clientset) AllocationV1() allocationv1.AllocationV1Interface {
	return c.allocationV1
}

// AutoscalingV1 retrieves the AutoscalingV1Client
func (c *Clientset) AutoscalingV1() autoscalingv1.AutoscalingV1Interface {
	return c.autoscalingV1
}

// MulticlusterV1 retrieves the MulticlusterV1Client
func (c *Clientset) MulticlusterV1() multiclusterv1.MulticlusterV1Interface {
	return c.multiclusterV1
}

// Discovery retrieves the DiscoveryClient
func (c *Clientset) Discovery() discovery.DiscoveryInterface {
	if c == nil {
		return nil
	}
	return c.DiscoveryClient
}

// NewForConfig creates a new Clientset for the given config.
// If config's RateLimiter is not set and QPS and Burst are acceptable,
// NewForConfig will generate a rate-limiter in configShallowCopy.
func NewForConfig(c *rest.Config) (*Clientset, error) {
	configShallowCopy := *c
	if configShallowCopy.RateLimiter == nil && configShallowCopy.QPS > 0 {
		if configShallowCopy.Burst <= 0 {
			return nil, fmt.Errorf("burst is required to be greater than 0 when RateLimiter is not set and QPS is set to greater than 0")
		}
		configShallowCopy.RateLimiter = flowcontrol.NewTokenBucketRateLimiter(configShallowCopy.QPS, configShallowCopy.Burst)
	}
	var cs Clientset
	var err error
	cs.agonesV1, err = agonesv1.NewForConfig(&configShallowCopy)
	if err != nil {
		return nil, err
	}
	cs.allocationV1, err = allocationv1.NewForConfig(&configShallowCopy)
	if err != nil {
		return nil, err
	}
	cs.autoscalingV1, err = autoscalingv1.NewForConfig(&configShallowCopy)
	if err != nil {
		return nil, err
	}
	cs.multiclusterV1, err = multiclusterv1.NewForConfig(&configShallowCopy)
	if err != nil {
		return nil, err
	}

	cs.DiscoveryClient, err = discovery.NewDiscoveryClientForConfig(&configShallowCopy)
	if err != nil {
		return nil, err
	}
	return &cs, nil
}

// NewForConfigOrDie creates a new Clientset for the given config and
// panics if there is an error in the config.
func NewForConfigOrDie(c *rest.Config) *Clientset {
	var cs Clientset
	cs.agonesV1 = agonesv1.NewForConfigOrDie(c)
	cs.allocationV1 = allocationv1.NewForConfigOrDie(c)
	cs.autoscalingV1 = autoscalingv1.NewForConfigOrDie(c)
	cs.multiclusterV1 = multiclusterv1.NewForConfigOrDie(c)

	cs.DiscoveryClient = discovery.NewDiscoveryClientForConfigOrDie(c)
	return &cs
}

// New creates a new Clientset for the given RESTClient.
func New(c rest.Interface) *Clientset {
	var cs Clientset
	cs.agonesV1 = agonesv1.New(c)
	cs.allocationV1 = allocationv1.New(c)
	cs.autoscalingV1 = autoscalingv1.New(c)
	cs.multiclusterV1 = multiclusterv1.New(c)

	cs.DiscoveryClient = discovery.NewDiscoveryClient(c)
	return &cs
}
